=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2007-09-03 07:02:12 +0000
+++ bzrlib/tests/__init__.py	2007-09-04 11:00:30 +0000
@@ -2641,3 +2641,21 @@
         new_id = "%s(%s)" % (new_test.id(), scenario[0])
         new_test.id = lambda: new_id
         return new_test
+
+
+def probe_unicode_in_user_encoding():
+    """Try to encode several unicode strings to use in unicode-aware tests.
+    Return first successfull match.
+
+    :return:  (unicode value, encoded plain string value) or (None, None)
+    """
+    possible_vals = [u'm\xb5', u'\xe1', u'\u0410']
+    for uni_val in possible_vals:
+        try:
+            str_val = uni_val.encode(bzrlib.user_encoding)
+        except UnicodeEncodeError:
+            # Try a different character
+            pass
+        else:
+            return uni_val, str_val
+    return None, None

=== modified file 'bzrlib/tests/blackbox/test_version.py'
--- bzrlib/tests/blackbox/test_version.py	2007-09-03 12:36:35 +0000
+++ bzrlib/tests/blackbox/test_version.py	2007-09-04 11:00:30 +0000
@@ -17,8 +17,13 @@
 """Black-box tests for bzr version."""
 
 import bzrlib
-from bzrlib.tests import TestCase
-from bzrlib import trace
+from bzrlib import osutils, trace
+from bzrlib.tests import (
+    probe_unicode_in_user_encoding,
+    TestCase,
+    TestCaseInTempDir,
+    TestSkipped,
+    )
 
 
 class TestVersion(TestCase):
@@ -34,21 +39,23 @@
         self.assertContainsRe(out, r'(?m)^  Bazaar log file:.*bzr\.log')
 
 
-class TestVersionUnicodeOutput(TestCase):
+class TestVersionUnicodeOutput(TestCaseInTempDir):
 
     def _check(self, args):
+        # Even though trace._bzr_log_filename variable
+        # is used only to keep actual log filename
+        # and changing this variable in selftest
+        # don't change main .bzr.log location,
+        # and therefore pretty safe,
+        # but we run these tests in separate temp dir
+        # with relative unicoded path
         old_trace_file = trace._bzr_log_filename
-        trace._bzr_log_filename = u'/\u1234/.bzr.log'
+        trace._bzr_log_filename = u'\u1234/.bzr.log'
         try:
             out = self.run_bzr(args)[0]
         finally:
             trace._bzr_log_filename = old_trace_file
         self.assertTrue(len(out) > 0)
-        self.assertEquals(1, out.count(bzrlib.__version__))
-        self.assertContainsRe(out, r"(?m)^  Python interpreter:")
-        self.assertContainsRe(out, r"(?m)^  Python standard library:")
-        self.assertContainsRe(out, r"(?m)^  bzrlib:")
-        self.assertContainsRe(out, r"(?m)^  Bazaar configuration:")
         self.assertContainsRe(out, r'(?m)^  Bazaar log file:.*bzr\.log')
 
     def test_command(self):
@@ -56,3 +63,14 @@
 
     def test_flag(self):
         self._check("--version")
+
+    def test_unicode_bzr_home(self):
+        uni_val, str_val = probe_unicode_in_user_encoding()
+        if uni_val is None:
+            raise TestSkipped('Cannot find a unicode character that works in'
+                              ' encoding %s' % (bzrlib.user_encoding,))
+
+        osutils.set_or_unset_env('BZR_HOME', str_val)
+        out = self.run_bzr("version")[0]
+        self.assertTrue(len(out) > 0)
+        self.assertContainsRe(out, r"(?m)^  Bazaar configuration: " + str_val)

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2007-08-21 05:08:31 +0000
+++ bzrlib/tests/test_osutils.py	2007-09-04 11:00:30 +0000
@@ -35,6 +35,7 @@
         pathjoin,
         )
 from bzrlib.tests import (
+        probe_unicode_in_user_encoding,
         StringIOWrapper,
         TestCase,
         TestCaseInTempDir,
@@ -1001,18 +1002,8 @@
         
         So Unicode strings must be encoded.
         """
-        # Try a few different characters, to see if we can get
-        # one that will be valid in the user_encoding
-        possible_vals = [u'm\xb5', u'\xe1', u'\u0410']
-        for uni_val in possible_vals:
-            try:
-                env_val = uni_val.encode(bzrlib.user_encoding)
-            except UnicodeEncodeError:
-                # Try a different character
-                pass
-            else:
-                break
-        else:
+        uni_val, env_val = probe_unicode_in_user_encoding()
+        if uni_val is None:
             raise TestSkipped('Cannot find a unicode character that works in'
                               ' encoding %s' % (bzrlib.user_encoding,))
 

=== modified file 'bzrlib/version.py'
--- bzrlib/version.py	2007-09-03 12:53:57 +0000
+++ bzrlib/version.py	2007-09-04 11:00:30 +0000
@@ -54,7 +54,10 @@
     else:
         print >>to_file, bzrlib.__path__[0]
     if show_config:
-        print >>to_file, "  Bazaar configuration:", config.config_dir()
+        config_dir = os.path.normpath(config.config_dir())  # use native slashes
+        if not isinstance(config_dir, unicode):
+            config_dir = config_dir.decode(bzrlib.user_encoding)
+        print >>to_file, "  Bazaar configuration:", config_dir
         print >>to_file, "  Bazaar log file:", trace._bzr_log_filename
     if show_copyright:
         print >>to_file

